<h1 align="center">Belvaio Request Id</h1>
<p align="center">
    <a href="https://pypi.python.org/pypi/belvaio-request-id"><img alt="Package version" src="https://img.shields.io/pypi/v/belvaio-request-id?style=for-the-badge"></a>
    <a href="https://pypistats.org/packages/belvaio-request-id"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/belvaio-request-id?style=for-the-badge"></a>
    <a href="https://travis-ci.com/belvo-finance/belvaio-request-id"><img alt="Travis" src="https://img.shields.io/travis/com/belvo-finance/belvaio-request-id/master?style=for-the-badge"></a>
    <a href="https://codecov.io/gh/belvo-finance/belvaio-request-id"><img alt="Coverage" src="https://img.shields.io/codecov/c/gh/belvo-finance/belvaio-request-id?style=for-the-badge"></a>
</p>

---

**Documentation**: [https://belvo-finance.github.io/belvaio-request-id](https://belvo-finance.github.io/belvaio-request-id/)

---

Belvaio Request Id is an [`aiohttp`][aiohttp] utils that help us to track request journey between services.

## Requirements

- Python 3.7+
- [`aiohttp`][aiohttp] >= 3.5

## Installation

```shell
$ pip install belvaio-request-id
```

## Example

**example.py**:

```python
```

## Contributing

The Belvo team happily welcomes contributions. [Guidelines][guidelines] will help you get ready to contribute to this project!

[aiohttp]: https://docs.aiohttp.org/en/stable/index.html
[guidelines]: CONTRIBUTING.md
